@@ -19,6 +19,8 @@ from qctrlcommons.node.registry import (
     TYPE_REGISTRY,
 )
 
+from qctrl.utils import PackageRegistry
+
 from .async_result import AsyncResult
 from .client_builder import (
     create_client_auth,
@@ -35,6 +37,8 @@ from .functions import (
 )
 from .namespaces import (
     BaseNamespace,
+    ToolkitCategory,
+    build_and_bind_toolkit,
     create_function_namespace,
     create_type_namespace,
 )
@@ -86,6 +90,9 @@ def build_and_bind_namespaces(qctrl: "Qctrl") -> None:
 
     setattr(qctrl, "functions", function_namespace)
     setattr(qctrl, "types", type_namespace)
+    if PackageRegistry.QCTRLTOOLKIT.is_installed():
+        toolkit = PackageRegistry.QCTRLTOOLKIT.import_pkg()
+        build_and_bind_toolkit(qctrl, ToolkitCategory.WORKFLOWS, toolkit)
 
 
 __all__ = ["build_and_bind_namespaces"]
