@@ -13,10 +13,34 @@
 """Dynamically created classes."""
 import inspect
 import sys
+from enum import Enum
 from functools import wraps
 from types import ModuleType
 from typing import Callable
 
+from qctrlcommons.exceptions import QctrlException
+
+
+class BoulderModule(Enum):
+    """Defines the modules in Boulder."""
+
+    QCTRL = "qctrl"
+    GRAPH = "graph"
+
+    @classmethod
+    def is_dynamic(cls, module: "BoulderModule"):
+        """Check whether a module is dynamic."""
+        return module is cls.QCTRL
+
+    @classmethod
+    def get_module(cls, name: str) -> "BoulderModule":
+        """Get module by name."""
+        module = getattr(cls, name.upper(), None)
+        if module is None:
+            raise QctrlException(f"module {name} not found")
+
+        return module
+
 
 def dynamic_class(submodule: str) -> Callable:
     """Decorator to register a dynamic class. The decorated function should
@@ -25,7 +49,7 @@ def dynamic_class(submodule: str) -> Callable:
     Parameters
     ----------
     submodule : str
-        the submodule name that the class should be registered under
+        The submodule name that the class should be registered under
         e.g. `types`
 
     Returns
@@ -38,7 +62,9 @@ def dynamic_class(submodule: str) -> Callable:
         @wraps(func)
         def decorator(*args, **kwargs):
             cls = func(*args, **kwargs)
-            register_dynamic_class(cls, submodule)
+            register_dynamic_class(
+                cls, submodule, BoulderModule.get_module(cls.__module__)
+            )
             return cls
 
         return decorator
@@ -46,13 +72,19 @@ def dynamic_class(submodule: str) -> Callable:
     return customized_decorator
 
 
-def register_dynamic_class(cls: type, submodule: str):
+def register_dynamic_class(cls: type, submodule: str, module: BoulderModule):
     """
     Registers the class to the given dynamic
     submodule.
     """
     assert inspect.isclass(cls)
-    module_name = f"qctrl.dynamic.{submodule}"
+
+    module_name = (
+        f"{module.value}.dynamic"
+        if BoulderModule.is_dynamic(module)
+        else f"{module.value}"
+    )
+    module_name += f".{submodule}"
     cls.__module__ = module_name
     cls.__package__ = module_name
 
