@@ -14,6 +14,7 @@
 import logging
 import os
 import sys
+import warnings
 import webbrowser
 from threading import Thread
 from typing import (
@@ -56,12 +57,20 @@ from .queries import (
     MeQuery,
 )
 from .utils import (
-    _check_qctrl_latest_version,
+    PackageRegistry,
     _get_mutation_result_type,
 )
 
 LOGGER = logging.getLogger(__name__)
 
+warnings.formatwarning = lambda message, *args, **kwargs: f"{message}\n"
+if sys.version_info.minor < 7:
+    warnings.warn(
+        "You are currently running with Python 3.6. "
+        "Support of Python 3.6 will be dropped in April 2022 "
+        "since it has reached end-of-life in December 2021.",
+    )
+
 
 class Qctrl:
     """A mediator class. Used to authenticate with Q-CTRL and access Q-CTRL features.
@@ -334,8 +343,9 @@ class Qctrl:
         """
         Use another thread to check qctrl version.
         """
-        thread = Thread(target=_check_qctrl_latest_version, daemon=True)
-        thread.start()
+        for package in PackageRegistry:
+            if not package.is_lazy() or package.is_installed():
+                Thread(target=package.check_latest_version, daemon=True).start()
 
 
 @tenacity.retry(
