@@ -43,7 +43,7 @@ class QctrlApplicationClient(WebApplicationClient):
     implements the verify_token helper method.
     """
 
-    REFRESH_THRESHOLD = 30  # seconds
+    REFRESH_THRESHOLD = 60  # seconds
 
     def verify_token(self):
         """
@@ -155,7 +155,11 @@ class QctrlOAuth2Session(OAuth2Session):
 
         except TokenExpiredError:
             if self.auto_refresh_url:
-                self.token = self.refresh_token(self.auto_refresh_url)
+                try:
+                    self.token = self.refresh_token(self.auto_refresh_url)
+                except Warning:
+                    self.authenticate()
+
                 if self.token_updater:
                     self.token_updater(self.token)
                 return self._client.access_token
