@@ -12,7 +12,6 @@
 # License for the specific language.
 # pylint:disable=missing-module-docstring
 from .activity_monitor import ActivityMonitorQuery
-from .create_token import CreateTokenQuery
 from .get_environment import (
     GetQueueInfoQuery,
     GetWorkerInfoQuery,
@@ -23,7 +22,6 @@ from .refresh_action import (
     MultiRefreshActionQuery,
     RefreshActionQuery,
 )
-from .refresh_token import RefreshTokenQuery
 from .start_action import (
     MultiStartActionQuery,
     StartActionQuery,
