@@ -11,8 +11,12 @@
 # distributed under the License is distributed on an "AS IS" BASIS. See the
 # License for the specific language.
 # pylint:disable=missing-module-docstring
+import importlib.util
 import logging
 import re
+import sys
+from collections import namedtuple
+from enum import Enum
 from functools import wraps
 from typing import (
     Any,
@@ -22,6 +26,7 @@ from typing import (
 )
 
 import commonmark
+import inflection
 import requests
 from gql.transport.exceptions import TransportServerError
 from graphql import (
@@ -36,7 +41,6 @@ from qctrlcommons.exceptions import QctrlException
 from requests import codes
 from requests.exceptions import HTTPError
 
-from qctrl import __version__
 from qctrl.constants import UNIVERSAL_ERROR_MESSAGE
 
 LOGGER = logging.getLogger(__name__)
@@ -221,29 +225,75 @@ def check_client_version(func):
     return _check_client_version
 
 
-def _check_qctrl_latest_version():
-    """
-    Checks the latest version of QCTRL in Pypi and
-    shows upgrade message if the current version is outdated.
-    """
-    latest_version = _get_latest_qctrl_version()
-    if version.parse(__version__) < version.parse(latest_version):
-        print(
-            f"Q-CTRL package update available. Your version is {__version__}. "
-            f"New version is {latest_version}.",
-        )
+# a namedtuple to define basic information of a package
+# name : the official name of the package
+# url : the URL for hosting the package on PyPI
+# is_lazy : a boolean flag. If true, meaning the package should be only
+# imported when locally available
+_PackageInfo = namedtuple("_PackageInfo", ["name", "url", "is_lazy"])
+_QCTRL_URL = "https://pypi.org/pypi/qctrl/json"
+_TOOLKIT_URL = "https://pypi.org/pypi/qctrl-toolkit/json"
 
 
-def _get_latest_qctrl_version() -> str:
+class PackageRegistry(Enum):
     """
-    Get the latest version of Q-CTRL python package in Pypi.
+    Lists Q-CTRL related packages.
+    """
+
+    QCTRL = _PackageInfo("Q-CTRL", _QCTRL_URL, False)
+    QCTRLTOOLKIT = _PackageInfo("Q-CTRL Toolkit", _TOOLKIT_URL, True)
+
+    def check_latest_version(self):
+        """
+        Checks the latest version of a package in PyPI and
+        shows upgrade message if the current version is outdated.
+        """
+        latest_version = _get_latest_version(self.value.url)
+        pkg = self.import_pkg()
+        local_version = getattr(pkg, "__version__")
+        if version.parse(local_version) < version.parse(latest_version):
+            print(
+                f"{self.value.name} package update available. Your version is {local_version}. "
+                f"New version is {latest_version}.",
+            )
+
+    def is_installed(self) -> bool:
+        """checks whether a package is locally available."""
+        return importlib.util.find_spec(self.get_package_name()) is not None
+
+    def is_lazy(self) -> bool:
+        """Checks if a package should be imported lazily."""
+        return self.value.is_lazy
+
+    def import_pkg(self):
+        """Import the package if it's not already in the sys modules."""
+        pkg_name = self.get_package_name()
+        pkg = sys.modules.get(pkg_name)
+        if pkg is None:
+            spec = importlib.util.find_spec(pkg_name)
+            if spec is None:
+                raise ImportError(f"{self.value.name} not found")
+            module = importlib.util.module_from_spec(spec)
+            sys.modules[pkg_name] = module
+            spec.loader.exec_module(module)
+            return sys.modules[pkg_name]
+        return pkg
+
+    def get_package_name(self) -> str:
+        """Gets the name of the package"""
+        return inflection.parameterize(self.value.name).replace("-", "")
+
+
+def _get_latest_version(url) -> str:
+    """
+    Get the latest version of Q-CTRL python package in PyPI.
 
     Returns
     -------
     str
-        latest version.
+        The latest version.
     """
-    contents = requests.get("https://pypi.org/pypi/qctrl/json").json()
+    contents = requests.get(url).json()
     latest_version = contents["info"]["version"]
     return latest_version
 
